function [ret,x0,str,ts,xts]=lp4(t,x,u,flag);
%LP4	is the M-file description of the SIMULINK system named LP4.
%	The block-diagram can be displayed by typing: LP4.
%
%	SYS=LP4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LP4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LP4 with a FLAG of zero:
%	[SIZES]=LP4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,792,592])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '4')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Gain',[sys,'/','Validation retour modle 1er ordre'])
set_param([sys,'/','Validation retour modle 1er ordre'],...
		'orientation',2,...
		'Gain','0',...
		'position',[345,110,375,140])

add_block('built-in/Transfer Fcn',[sys,'/',['Modle nominal',13,'1er ordre']])
set_param([sys,'/',['Modle nominal',13,'1er ordre']],...
		'Numerator','Ns',...
		'Denominator','Ds',...
		'position',[445,28,505,62])


%     Subsystem  ['PI pour',13,'modle simple'].

new_system([sys,'/',['PI pour',13,'modle simple']])
set_param([sys,'/',['PI pour',13,'modle simple']],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/',['PI pour',13,'modle simple/Sum']])
set_param([sys,'/',['PI pour',13,'modle simple/Sum']],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/',['PI pour',13,'modle simple/D']])
set_param([sys,'/',['PI pour',13,'modle simple/D']],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/',['PI pour',13,'modle simple/Proportional']])
set_param([sys,'/',['PI pour',13,'modle simple/Proportional']],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/',['PI pour',13,'modle simple/Integral']])
set_param([sys,'/',['PI pour',13,'modle simple/Integral']],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/',['PI pour',13,'modle simple/Derivative']])
set_param([sys,'/',['PI pour',13,'modle simple/Derivative']],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/',['PI pour',13,'modle simple/Out_1']])
set_param([sys,'/',['PI pour',13,'modle simple/Out_1']],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/',['PI pour',13,'modle simple/In_1']])
set_param([sys,'/',['PI pour',13,'modle simple/In_1']],...
		'position',[25,65,45,85])
add_line([sys,'/',['PI pour',13,'modle simple']],[120,140;145,140])
add_line([sys,'/',['PI pour',13,'modle simple']],[270,75;285,75])
add_line([sys,'/',['PI pour',13,'modle simple']],[50,75;105,75])
add_line([sys,'/',['PI pour',13,'modle simple']],[65,75;65,140;90,140])
add_line([sys,'/',['PI pour',13,'modle simple']],[80,75;80,25;115,25])
add_line([sys,'/',['PI pour',13,'modle simple']],[195,140;215,140;215,85;240,85])
add_line([sys,'/',['PI pour',13,'modle simple']],[150,75;240,75])
add_line([sys,'/',['PI pour',13,'modle simple']],[145,25;210,25;210,65;240,65])
set_param([sys,'/',['PI pour',13,'modle simple']],...
		'Mask Display','PID',...
		'Mask Type','PID Controller')
set_param([sys,'/',['PI pour',13,'modle simple']],...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:',...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/',['PI pour',13,'modle simple']],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/',['PI pour',13,'modle simple']],...
		'Mask Entries','Ps%=A*T\/Is%=A\/0\/')


%     Finished composite block ['PI pour',13,'modle simple'].

set_param([sys,'/',['PI pour',13,'modle simple']],...
		'position',[320,29,360,61])

add_block('built-in/Sum',[sys,'/','Diff.'])
set_param([sys,'/','Diff.'],...
		'inputs','+-',...
		'position',[240,35,260,55])

add_block('built-in/Sum',[sys,'/','Diff.1'])
set_param([sys,'/','Diff.1'],...
		'inputs','+-',...
		'position',[235,225,255,245])


%     Subsystem  ['PID pour',13,'2nd ordre'].

new_system([sys,'/',['PID pour',13,'2nd ordre']])
set_param([sys,'/',['PID pour',13,'2nd ordre']],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/',['PID pour',13,'2nd ordre/Sum']])
set_param([sys,'/',['PID pour',13,'2nd ordre/Sum']],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/',['PID pour',13,'2nd ordre/D']])
set_param([sys,'/',['PID pour',13,'2nd ordre/D']],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/',['PID pour',13,'2nd ordre/Proportional']])
set_param([sys,'/',['PID pour',13,'2nd ordre/Proportional']],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/',['PID pour',13,'2nd ordre/Integral']])
set_param([sys,'/',['PID pour',13,'2nd ordre/Integral']],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/',['PID pour',13,'2nd ordre/Derivative']])
set_param([sys,'/',['PID pour',13,'2nd ordre/Derivative']],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/',['PID pour',13,'2nd ordre/Out_1']])
set_param([sys,'/',['PID pour',13,'2nd ordre/Out_1']],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/',['PID pour',13,'2nd ordre/In_1']])
set_param([sys,'/',['PID pour',13,'2nd ordre/In_1']],...
		'position',[25,65,45,85])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[120,140;145,140])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[270,75;285,75])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[50,75;105,75])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[65,75;65,140;90,140])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[80,75;80,25;115,25])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[195,140;215,140;215,85;240,85])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[150,75;240,75])
add_line([sys,'/',['PID pour',13,'2nd ordre']],[145,25;210,25;210,65;240,65])
set_param([sys,'/',['PID pour',13,'2nd ordre']],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/',['PID pour',13,'2nd ordre']],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/',['PID pour',13,'2nd ordre']],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/',['PID pour',13,'2nd ordre']],...
		'Mask Entries','P%=A*(T+Td)\/I%=A\/D1%=A*T*Td\/')


%     Finished composite block ['PID pour',13,'2nd ordre'].

set_param([sys,'/',['PID pour',13,'2nd ordre']],...
		'position',[290,219,330,251])

add_block('built-in/Saturation',[sys,'/','Saturations'])
set_param([sys,'/','Saturations'],...
		'Lower Limit','-Vsat',...
		'Upper Limit','Vsat',...
		'position',[415,223,445,247])

add_block('built-in/Transfer Fcn',[sys,'/',['Modle nominal',13,'2nd ordre']])
set_param([sys,'/',['Modle nominal',13,'2nd ordre']],...
		'Numerator','N',...
		'Denominator','D',...
		'position',[520,218,580,252])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[470,166,500,199])

add_block('built-in/Gain',[sys,'/','Validation retour modle 2nd ordre'])
set_param([sys,'/','Validation retour modle 2nd ordre'],...
		'orientation',2,...
		'Gain','0',...
		'position',[345,300,375,330])


%     Subsystem  ['PID pour',13,'modle incertain'].

new_system([sys,'/',['PID pour',13,'modle incertain']])
set_param([sys,'/',['PID pour',13,'modle incertain']],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/',['PID pour',13,'modle incertain/Sum']])
set_param([sys,'/',['PID pour',13,'modle incertain/Sum']],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/',['PID pour',13,'modle incertain/D']])
set_param([sys,'/',['PID pour',13,'modle incertain/D']],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/',['PID pour',13,'modle incertain/Proportional']])
set_param([sys,'/',['PID pour',13,'modle incertain/Proportional']],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/',['PID pour',13,'modle incertain/Integral']])
set_param([sys,'/',['PID pour',13,'modle incertain/Integral']],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/',['PID pour',13,'modle incertain/Derivative']])
set_param([sys,'/',['PID pour',13,'modle incertain/Derivative']],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/',['PID pour',13,'modle incertain/Out_1']])
set_param([sys,'/',['PID pour',13,'modle incertain/Out_1']],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/',['PID pour',13,'modle incertain/In_1']])
set_param([sys,'/',['PID pour',13,'modle incertain/In_1']],...
		'position',[25,65,45,85])
add_line([sys,'/',['PID pour',13,'modle incertain']],[120,140;145,140])
add_line([sys,'/',['PID pour',13,'modle incertain']],[270,75;285,75])
add_line([sys,'/',['PID pour',13,'modle incertain']],[50,75;105,75])
add_line([sys,'/',['PID pour',13,'modle incertain']],[65,75;65,140;90,140])
add_line([sys,'/',['PID pour',13,'modle incertain']],[80,75;80,25;115,25])
add_line([sys,'/',['PID pour',13,'modle incertain']],[195,140;215,140;215,85;240,85])
add_line([sys,'/',['PID pour',13,'modle incertain']],[150,75;240,75])
add_line([sys,'/',['PID pour',13,'modle incertain']],[145,25;210,25;210,65;240,65])
set_param([sys,'/',['PID pour',13,'modle incertain']],...
		'Mask Display','PID',...
		'Mask Type','PID Controller')
set_param([sys,'/',['PID pour',13,'modle incertain']],...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:',...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/',['PID pour',13,'modle incertain']],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/',['PID pour',13,'modle incertain']],...
		'Mask Entries','P\/I\/D1\/')


%     Finished composite block ['PID pour',13,'modle incertain'].

set_param([sys,'/',['PID pour',13,'modle incertain']],...
		'position',[295,409,335,441])

add_block('built-in/Sum',[sys,'/','Diff.2'])
set_param([sys,'/','Diff.2'],...
		'inputs','+-',...
		'position',[235,414,255,436])

add_block('built-in/Sum',[sys,'/','Som.'])
set_param([sys,'/','Som.'],...
		'position',[365,165,385,185])

add_block('built-in/Sum',[sys,'/','Som.1'])
set_param([sys,'/','Som.1'],...
		'position',[365,355,385,375])

add_block('built-in/Saturation',[sys,'/',['Saturations pour',13,'modle incertain']])
set_param([sys,'/',['Saturations pour',13,'modle incertain']],...
		'Lower Limit','-Vsat',...
		'Upper Limit','Vsat',...
		'position',[455,353,485,377])

add_block('built-in/Transfer Fcn',[sys,'/',['Modle incertain',13,'2nd ordre1']])
set_param([sys,'/',['Modle incertain',13,'2nd ordre1']],...
		'Numerator','Ni',...
		'Denominator','Di',...
		'position',[580,348,640,382])

add_block('built-in/Step Fcn',[sys,'/',['Perturbation',13,'en chelon',13,'t=2s']])
set_param([sys,'/',['Perturbation',13,'en chelon',13,'t=2s']],...
		'Time','0',...
		'position',[85,160,105,180])

add_block('built-in/Step Fcn',[sys,'/',['Echelon',13,'unitaire']])
set_param([sys,'/',['Echelon',13,'unitaire']],...
		'Time','0',...
		'position',[160,220,180,240])


%     Subsystem  ['Mesure des commandes',13,'avant et prs saturation'].

new_system([sys,'/',['Mesure des commandes',13,'avant et prs saturation']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Mesure des commandes',13,'avant et prs saturation/x']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Mesure des commandes',13,'avant et prs saturation/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],[90,65;125,65])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Mesure des commandes',13,'avant et prs saturation'].

set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation']],...
		'position',[605,120,635,160])

add_block('built-in/Gain',[sys,'/',['Visu modle',13,'simple',13,'']])
set_param([sys,'/',['Visu modle',13,'simple',13,'']],...
		'position',[675,30,705,60])

add_block('built-in/Gain',[sys,'/',['Visu modle',13,'complet']])
set_param([sys,'/',['Visu modle',13,'complet']],...
		'position',[645,220,675,250])

add_block('built-in/Gain',[sys,'/',['Visu modle',13,'incertain']])
set_param([sys,'/',['Visu modle',13,'incertain']],...
		'Gain','0',...
		'position',[710,350,740,380])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'inputs','3',...
		'position',[765,218,795,252])

add_block('built-in/Gain',[sys,'/','Validation retour modle incertain'])
set_param([sys,'/','Validation retour modle incertain'],...
		'orientation',2,...
		'Gain','0',...
		'position',[360,505,390,535])


%     Subsystem  ['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)'].

new_system([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)/x']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'position',[130,55,180,75])
add_line([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],[90,65;125,65])
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)'].

set_param([sys,'/',['Mesure des commandes',13,'avant et prs saturation',13,'(modle incertain)']],...
		'position',[570,425,600,465])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[445,426,475,459])


%     Subsystem  ['Mesure des',13,'sorties'].

new_system([sys,'/',['Mesure des',13,'sorties']])
set_param([sys,'/',['Mesure des',13,'sorties']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Mesure des',13,'sorties/x']])
set_param([sys,'/',['Mesure des',13,'sorties/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Mesure des',13,'sorties/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Mesure des',13,'sorties/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunyst',...
		'parameters','ax, color, npts, dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Mesure des',13,'sorties']],[90,65;125,65])
set_param([sys,'/',['Mesure des',13,'sorties']],...
		'Mask Display','plot(0,0,100,100,[83,76,63,52,42,38,28,16,11,84,11,11,11,90,90,11],[75,58,47,54,72,80,84,74,65,65,65,90,40,40,90,90])',...
		'Mask Type','Storage scope.')
set_param([sys,'/',['Mesure des',13,'sorties']],...
		'Mask Dialogue','Storage scope using MATLAB graph window.\nEnter plotting ranges and line type.|Initial Time Range:|Initial y-min:|Initial y-max:|Storage pts.:|Line type (rgbw-.:xo):')
set_param([sys,'/',['Mesure des',13,'sorties']],...
		'Mask Translate','npts = @4; color = @5; ax = [0, @1, @2, @3]; dt=-1;')
set_param([sys,'/',['Mesure des',13,'sorties']],...
		'Mask Help','This block uses a MATLAB figure window to plot the input signal.  The graph limits are automatically scaled to the min and max values of the signal stored in the scope''s signal buffer.  Line type must be in quotes.  See the M-file sfunyst.m.')
set_param([sys,'/',['Mesure des',13,'sorties']],...
		'Mask Entries','5\/-10\/10\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Mesure des',13,'sorties'].

set_param([sys,'/',['Mesure des',13,'sorties']],...
		'position',[835,215,865,255])
add_line(sys,[265,45;315,45])
add_line(sys,[365,45;440,45])
add_line(sys,[510,45;535,45;535,125;380,125])
add_line(sys,[340,125;220,125;220,50;235,50])
add_line(sys,[185,230;205,230;205,40;235,40])
add_line(sys,[110,170;360,170])
add_line(sys,[205,210;205,230;230,230])
add_line(sys,[260,235;285,235])
add_line(sys,[335,235;335,180;360,180])
add_line(sys,[335,235;410,235])
add_line(sys,[450,235;515,235])
add_line(sys,[390,175;465,175])
add_line(sys,[450,235;450,190;465,190])
add_line(sys,[505,185;520,185;520,140;600,140])
add_line(sys,[585,235;610,235;610,315;380,315])
add_line(sys,[340,315;215,315;215,240;230,240])
add_line(sys,[535,45;670,45])
add_line(sys,[205,230;205,420;230,420])
add_line(sys,[260,425;290,425])
add_line(sys,[155,170;140,170;140,360;360,360])
add_line(sys,[390,365;450,365])
add_line(sys,[340,425;340,370;360,370])
add_line(sys,[490,365;575,365])
add_line(sys,[405,365;405,435;440,435])
add_line(sys,[535,365;535,420;425,420;425,450;440,450])
add_line(sys,[480,445;565,445])
add_line(sys,[605,235;640,235])
add_line(sys,[645,365;705,365])
add_line(sys,[670,365;675,365;675,520;395,520])
add_line(sys,[355,520;195,520;195,430;230,430])
add_line(sys,[680,235;760,235])
add_line(sys,[710,45;740,45;740,225;760,225])
add_line(sys,[745,365;750,365;760,245])
add_line(sys,[800,235;830,235])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
